@@ -1,5 +1,5 @@
 ;;; emacspeak-tetris.el --- Speech enable game of Tetris
-;;; $Id: emacspeak-tetris.el 6412 2009-12-02 00:55:01Z tv.raman.tv $
+;;; $Id: emacspeak-tetris.el 6641 2010-11-23 23:52:58Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $ 
 ;;; Description: Auditory interface to tetris
 ;;; Keywords: Emacspeak, Speak, Spoken Output, tetris
@@ -62,20 +62,20 @@
   (require 'emacspeak-pronounce)
   (unless emacspeak-tetris-pronunciations-defined
     (setq emacspeak-tetris-pronunciations-defined t)
-    (mapcar
-     #'(lambda (entry)
-         (emacspeak-pronounce-add-dictionary-entry 'tetris-mode
-                                                   (car entry) (cdr entry)))
-     '(("" . " 1 ")
-       ("" . " 6 ")
-       ("" . " 7 ")
-       ("" . " 5 ")
-       ("" . " 4 ")
-       ("" . " 3 ")
-       ("" . " 2 ")
-       (" " . "-")
-       ("" . "")                      ;border char
-       ("." . ""))))
+    (emacspeak-pronounce-set-dictionary
+       'tetris-mode
+       '(("." . "")
+         ("" . "")                    ;ascii 8: border
+         (" " . " 1 ")                 ; ascii 0: block
+         ("" . " 2 ")                 ; Ascii 1: right elbow
+         ("" . " 3 ")                 ; ascii 2: left elbow
+         ("" . " 4 ")                 ; ascii 3: Z
+         ("" . " 5 ")                 ; Ascii 4: S
+         ("" . " 6 ")                 ; Ascii 5: inverted T
+         ("" . " 7 ")                 ; ascii 6: Edge
+         ("." . "")
+         ("" . "-")                   ; ascii 7: blank
+         )))
   (when (or (not (boundp 'emacspeak-pronounce-pronunciation-table))
             (not emacspeak-pronounce-pronunciation-table))
     (emacspeak-pronounce-toggle-use-of-dictionaries)))
@@ -199,7 +199,7 @@
 ;;}}}
 ;;{{{  Advice
 
-(defvar emacspeak-tetris-tick-period 15
+(defvar emacspeak-tetris-tick-period 1
   "*Set this to a convenient value so you get time to look at what is
 going on. Reduce it as you get better.")
 
@@ -357,45 +357,41 @@ concentration and the game is a good mental challenge. "
   "Provide spoken feedback"
   (emacspeak-tetris-speak-current-shape))
 
-(defadvice tetris-rotate-next (after emacspeak pre act comp)
-  "Provide auditory feedback"
-  (when (interactive-p)
-    (emacspeak-tetris-speak-current-shape)))
-
-(defadvice tetris-rotate-prev (after emacspeak pre act comp)
-  "Provide auditory feedback"
-  (when (interactive-p)
-    (emacspeak-tetris-speak-current-shape)))
-
+(loop for f in
+      '(tetris-rotate-prev tetris-rotate-next)
+      do
+      (eval
+       `(defadvice ,f (after emacspeak pre act comp)
+          "Provide auditory feedback"
+          (when (interactive-p) (emacspeak-tetris-speak-current-shape)))))
+           
 (defadvice tetris-move-left-edge (after emacspeak pre act comp)
   "Speak coordinates"
   (when (interactive-p)
-    (emacspeak-tetris-speak-column)))
+    (emacspeak-auditory-icon 'select-object)
+    (emacspeak-tetris-speak-current-shape-and-coordinates)))
 
 (defadvice tetris-move-right-edge (after emacspeak pre act comp)
   "Speak coordinates"
   (when (interactive-p)
-    (emacspeak-tetris-speak-column)))
-
-(defadvice tetris-move-to-x-pos (after emacspeak pre act comp)
-  "Speak coordinates"
-  (when (interactive-p)
-    (emacspeak-tetris-speak-column)))
+    (emacspeak-auditory-icon 'select-object)
+    (emacspeak-tetris-speak-current-shape-and-coordinates)))
 
 (defadvice tetris-move-left (after emacspeak pre act comp)
   "Speak coordinates"
   (when (interactive-p)
-    (emacspeak-tetris-speak-column)))
+    (emacspeak-tetris-speak-current-shape-and-coordinates)))
 
 (defadvice tetris-move-right (after emacspeak pre act comp)
   "Speak coordinates"
   (when (interactive-p)
-    (emacspeak-tetris-speak-column)))
+    (emacspeak-tetris-speak-current-shape-and-coordinates)))
 
 (defadvice tetris-move-bottom (after emacspeak pre act comp)
   "Provide auditory feedback as the tile falls"
   (when (interactive-p)
     (emacspeak-auditory-icon 'close-object)))
+
 (defvar emacspeak-tetris-filled-a-row nil
   "Temporary flag indicating if we just filled a row.")
 
@@ -520,7 +516,8 @@ a(defun tetris-move-right-edge ()
         (setq tetris-pos-x (1- tetris-pos-x))
         (setq hit (tetris-test-shape))
         (incf diff))))
-    (tetris-draw-shape)))
+    (tetris-draw-shape)
+    (emacspeak-tetris-speak-current-shape-and-coordinates)))
 
 ;;}}}
 ;;{{{ column browsing
